# `replit` Python Module


The [Repl.it](https://repl.it/) Python environment does not require any platform-specific code, however, these optional utilities provide additional platform features in a simple and accessible way.

![compute](https://github.com/kennethreitz42/replit-py/blob/kr-cleanup/ext/readme.gif?raw=true)


*Example*: [Repl.it DB](https://docs.repl.it/misc/database) is an HTTP service, but an optional Python client (here!) is available.


### `>>> import replit`

This repository is the home for the `replit` Python package, which provides:

- A fully-featured database client for [Repl.it DB](https://docs.repl.it/misc/database). **[[docs]](https://example.com)**
- A **work in progress** Repl.it user profile lookup. **[[docs]](https://example.com)**
- A Flask application decorator for ensuring Repl.it Auth required on specific routes. **[[docs]](https://example.com)**

& other helpful toys and utilities, like...

- A simple audio library that can play tones and audio files!
- Some helpful functions for displaying ANSI colors within interactive terminal sessions.

### Open Source License

This library is licensed under the [ISC License](https://en.wikipedia.org/wiki/ISC_license) and is free for you to use, change, or even profit from!
